@@ -906,7 +906,7 @@ def visualize_fanio(fan_ins, fan_outs):
     fig1.suptitle("Actiavation Dists")
     fig2.suptitle("Fan Out Dists")
 
-    for i in range(len(fan_ins)):
+    for i in range(len(fan_outs)):
 
         fi_axes[i].hist(fan_ins[i+1].reshape(1, -1)[0], bins=20, color="#00ACCD")
         fi_axes[i].set_xlabel('Layer' + str(i+1))
